@@ -2,7 +2,7 @@ from abc import ABC
 
 import bs4
 
-from scraper import _util as util
+from . import _util as util
 
 
 __all__ = ["Parser"]
